@@ -26,9 +26,9 @@ test_razip_gzcompressed <- function()
     writeLines(readLines(src), con, sep="\n")
     close(con)
     rzdest <- razip(gzdest)
-    checkIdentical(src, indexFa(src))
-    checkIdentical(gzdest, indexFa(gzdest))
-    checkIdentical(rzdest, indexFa(rzdest))
+    checkIdentical(paste0(src, ".fai"), indexFa(src))
+    checkIdentical(paste0(gzdest, ".fai"), indexFa(gzdest))
+    checkIdentical(paste0(rzdest, ".fai"), indexFa(rzdest))
     src <- scanFa(src, param=as(seqinfo(FaFile(rzdest)), "GRanges"))
     rz <- scanFa(rzdest, param=as(seqinfo(FaFile(rzdest)), "GRanges"))
     gz <- scanFa(rzdest, param=as(seqinfo(FaFile(rzdest)), "GRanges"))
