@@ -350,20 +350,40 @@ static bam_index_t *bam_index_load_core(FILE *fp)
 		khint_t k;
 		int j, ret;
 		bam_binlist_t *p;
+		size_t status;
 		index = idx->index[i] = kh_init(i);
 		// load binning index
-		fread(&size, 4, 1, fp);
+		status = fread(&size, 4, 1, fp);
+		if (status != 1) {
+		    fprintf(stderr, "[bam_index_load] corrupt index (0)?\n");
+		    bam_index_destroy(idx);
+		    return 0;
+		}
 		if (bam_is_be) bam_swap_endian_4p(&size);
 		for (j = 0; j < (int)size; ++j) {
-			fread(&key, 4, 1, fp);
+			status = fread(&key, 4, 1, fp);
+			if (status != 1) {
+			    fprintf(stderr, "[bam_index_load] corrupt index (1)?\n");
+			    return 0;
+			}
 			if (bam_is_be) bam_swap_endian_4p(&key);
 			k = kh_put(i, index, key, &ret);
 			p = &kh_value(index, k);
-			fread(&p->n, 4, 1, fp);
+			status = fread(&p->n, 4, 1, fp);
+			if (status != 1) {
+			    fprintf(stderr, "[bam_index_load] corrupt index? (2)\n");
+			    /* idx memory leak */
+			    return 0;
+			}
 			if (bam_is_be) bam_swap_endian_4p(&p->n);
 			p->m = p->n;
 			p->list = (pair64_t*)malloc(p->m * 16);
-			fread(p->list, 16, p->n, fp);
+			status = fread(p->list, 16, p->n, fp);
+			if (status != p->n) {
+			    fprintf(stderr, "[bam_index_load] corrupt index? (3)\n");
+			    /* idx memory leak */
+			    return 0;
+			}
 			if (bam_is_be) {
 				int x;
 				for (x = 0; x < p->n; ++x) {
@@ -373,11 +393,21 @@ static bam_index_t *bam_index_load_core(FILE *fp)
 			}
 		}
 		// load linear index
-		fread(&index2->n, 4, 1, fp);
+		status = fread(&index2->n, 4, 1, fp);
+		if (status != 1) {
+		    fprintf(stderr, "[bam_index_load] corrupt index? (4)\n");
+		    /* idx memory leak */
+		    return 0;
+		}
 		if (bam_is_be) bam_swap_endian_4p(&index2->n);
 		index2->m = index2->n;
 		index2->offset = (uint64_t*)calloc(index2->m, 8);
-		fread(index2->offset, index2->n, 8, fp);
+		status = fread(index2->offset, index2->n, 8, fp);
+		if (index2->n && status != 8) {
+		    fprintf(stderr, "[bam_index_load] corrupt index? (5)\n");
+		    /* idx memory leak */
+		    return 0;
+		}
 		if (bam_is_be)
 			for (j = 0; j < index2->n; ++j) bam_swap_endian_8p(&index2->offset[j]);
 	}
